pub struct ActReply {
pub actions_run: usize,
pub observation: Option<Observation>,
pub opened_screen: Option<u8>,
}Expand description
Reply to POST /sessions/{id}/act.
Fields
actions_run: usizeobservation: Option<Observation>The closing screenshot, when the batch asked for one.
opened_screen: Option<u8>Screen number this batch opened for the session, when it was the session’s first call.