pub struct CreateSession {
pub title: SessionTitle,
pub screen_size: ScreenSize,
pub shell_timeouts: ShellTimeouts,
pub owner: OwnerId,
pub idle_secs: NonZeroU32,
}Expand description
Body of POST /sessions.
Fields
title: SessionTitlescreen_size: ScreenSizeSize of the session’s screen, applied when the screen opens.
shell_timeouts: ShellTimeoutsTimeouts for the session’s shell commands.
owner: OwnerIdThe MCP server process that keeps the session alive with heartbeats.
idle_secs: NonZeroU32Seconds without agent calls after which the session ends.