pub struct ShellReply {
pub outcome: ShellOutcome,
pub duration_ms: u64,
pub stdout: String,
pub stderr: String,
}Expand description
Reply to POST /sessions/{id}/shell.
Fields
outcome: ShellOutcomeduration_ms: u64stdout: StringStandard output, shortened in the middle when it is very long.
stderr: StringStandard error, shortened in the middle when it is very long.