pub fn viewer_link(host_port: u16, key: &str) -> String
Link that opens the viewer page when the host publishes it on host_port.
host_port
The password after #key= stays in the browser and is never sent to the server in a request line.
#key=